#[cfg(not(tarpaulin_include))]
pub mod bat;
pub mod git;
pub mod helpwrap;
pub mod path;
pub mod process;
pub mod regex_replacement;
pub mod round_char_boundary;
pub mod syntect;
pub mod tabs;
pub mod workarounds;
